Module error

Module error 

Syntax error types for the Nash parser.

Ported from Elm’s Reporting/Error/Syntax.hs. These types form a nested hierarchy that enables high-quality error messages.

Note: Type, Expr, Pattern here are ERROR types describing parse failures, not AST types. They are allocated in the arena like everything else.

Enums

BadOperator
Case
Char
CustomType
Decl
DeclDef
DeclType
Def
Destruct
Error
Escape
Exposing
Expr
Func
If
Let
List
Module
Number
PList
PRecord
PTuple
Pattern
Port
Record
Space
StringError
TRecord
TTuple
Tuple
Type
TypeAlias